summaryrefslogtreecommitdiff
path: root/Lib/idlelib/macosx.py
diff options
context:
space:
mode:
Diffstat (limited to 'Lib/idlelib/macosx.py')
-rw-r--r--Lib/idlelib/macosx.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/Lib/idlelib/macosx.py b/Lib/idlelib/macosx.py
index d3ae224100..8f8484a370 100644
--- a/Lib/idlelib/macosx.py
+++ b/Lib/idlelib/macosx.py
@@ -1,5 +1,5 @@
"""
-A number of functions that enhance IDLE on Mac OSX.
+A number of functions that enhance IDLE on macOS.
"""
from sys import platform # Used in _init_tk_type, changed by test.
@@ -192,7 +192,7 @@ def overrideRootMenu(root, flist):
root.bind('<<close-all-windows>>', flist.close_all_callback)
# The binding above doesn't reliably work on all versions of Tk
# on MacOSX. Adding command definition below does seem to do the
# right thing for now.
root.createcommand('exit', flist.close_all_callback)
@@ -192,7 +192,7 @@ def overrideRootMenu(root, flist):
root.bind('<<close-all-windows>>', flist.close_all_callback)
# The binding above doesn't reliably work on all versions of Tk
- # on MacOSX. Adding command definition below does seem to do the
+ # on macOS. Adding command definition below does seem to do the
# right thing for now.
root.createcommand('exit', flist.close_all_callback)